<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:user="vbscript:code"
  xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:marc="http://www.loc.gov/MARC21/slim"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="user marc msxsl">
  <xsl:import href="MARC21slimUtils.xsl"/>
  <xsl:output method="xml" encoding="UTF-8" indent="yes"
    doctype-system="ead.dtd"
    doctype-public="+//ISBN 1-931666-00-8//DTD ead.dtd (Encoded Archival Description (EAD) Version 2.0)//EN"/>
  
  <msxsl:script language="VBScript" implements-prefix="user">
  <![CDATA[  
    '---------------------------------------------------------------------
    'converts current date to YYYYMMDD format

    function current_date()
    current_date = cstr(Year(Now))
    end function

    function current_date_normalized()
    current_date_normalized = cstr(Year(Now))
    current_date_normalized = Replace(current_date_normalized, "-", "/")
    end function

    function ProperCase(sText)
    '*** Converts text to proper case e.g.  ***'
    '*** surname = Surname      ***'
    '*** o'connor = O'Connor                ***'

    Dim a, iLen, bSpace, tmpX, tmpFull
    
    iLen = Len(sText)
    For a = 1 To iLen
    If a <> 1 Then 'just to make sure 1st character is upper and the rest lower'
    If bSpace = True Then
    tmpX = UCase(mid(sText,a,1))
    bSpace = False
    Else
    tmpX=LCase(mid(sText,a,1))
    If tmpX = " " Or tmpX = "'" Then bSpace = True
    End if
    Else
    tmpX = UCase(mid(sText,a,1))
    End if
    tmpFull = tmpFull & tmpX
    Next
    ProperCase = tmpFull
    End Function
    
    function BuildAbstract(s520, s545)
    Dim firstpart
    Dim secondpart
    
    if len(s520)>0 then
       if instr(s520, ".  ")>0 then
          firstpart = Mid(s520, 1, instr(s520, ".  ") + 2)
       else
          firstpart = s520
          if instr(firstpart, ".") = 0 then
            firstpart = firstpart + ".  "
          else 
            firstpart = firstpart + "  "
          end if
       end if
    end if
    
    if len(s545) > 0 then
       if instr(s545, ".  ")>0 then
          secondpart = Mid(s545, 1, instr(s545, ".  ") + 2)
       else
          secondpart = s545
          if instr(secondpart, ".") = 0 then
             secondpart = secondpart + "."
          end if
       end if
    end if
    
    BuildAbstract = firstpart + secondpart
    
    end function
    
    function IsAcqu(sText)
       if instr(lcase(stext), "gift of") > 0 then
          IsAcqu = "true"
       else 
          IsAcqu = "false"
       end if
    end function
    
    function buildFilename(sname)
       Dim name
       
       name = "OHY_" + replace(sname, " ", "")
       
       buildFilename = name
    
    end function
    
  ]]>
  </msxsl:script>


  <xsl:template match="/">
    <?filetitle?>
    <ead>
      <!--The following section is header information for web display of the finding aid-->
      <eadheader langencoding="iso639-2b" scriptencoding="iso15924" relatedencoding="dc"
        repositoryencoding="iso15511" countryencoding="iso3166-1" dateencoding="iso8601" id="a0">
        <eadid countrycode="us" encodinganalog="identifier" mainagencycode="ohy">
          <xsl:if test="//marc:record/marc:datafield[@tag=099]">
            <xsl:value-of select="user:buildFilename(string(//marc:record/marc:datafield[@tag=099]/marc:subfield[@code='a']/.))"
            />
          </xsl:if>
        </eadid>

        <filedesc>
          <titlestmt>
            <titleproper encodinganalog="title">
              <xsl:if test="//marc:record/marc:datafield[@tag=245]">
                <xsl:variable name="tmpTitle" select ="string(//marc:record/marc:datafield[@tag=245]/marc:subfield[@code='a']/.)" />
                <xsl:value-of
                  select="user:ProperCase($tmpTitle)"/>
              </xsl:if>
              <xsl:if test="//marc:record/marc:datafield[@tag=245]/marc:subfield[@code='f']">
                <date encodinganalog="Date">
                  <xsl:value-of
                    select="//marc:record/marc:datafield[@tag=245]/marc:subfield[@code='f']/."/>
                </date>
              </xsl:if>
            </titleproper>
            
            <titleproper type="filing" altrender="nodisplay">
              <xsl:if test="//marc:record/marc:datafield[@tag=245]">
                <xsl:variable name="tmpTitle" select ="string(//marc:record/marc:datafield[@tag=245]/marc:subfield[@code='a']/.)" />
                <xsl:value-of
                  select="user:ProperCase($tmpTitle)"/>
              </xsl:if>
            </titleproper>
            
            <author encodinganalog="creator">Finding aid prepared by MarcEdit</author>

          </titlestmt>
          <publicationstmt>
            <publisher encodinganalog="publisher"> Oregon Historical Society Davies Family Research
                Library<extptr actuate="onload" show="embed" href="http://ohs.org/images/logo_2.gif"
              />
            </publisher>
            <date encodinganalog="date" type="inclusive" era="ce" calendar="gregorian">
              <xsl:attribute name="normal">
                <xsl:value-of select="user:current_date_normalized()" />
              </xsl:attribute>
              <xsl:value-of select="user:current_date()" />
            </date>
            <address>
              <addressline>Portland, OR  97205</addressline>
              <addressline>503-306-5240</addressline>
              <addressline>http://www.ohs.org/</addressline>
              <addressline>libreference@ohs.org</addressline>
            </address>

          </publicationstmt>
        </filedesc>


        <profiledesc>
          <creation encodinganalog="description"> Finding aid encoded by MarcEdit <date era="ce"
              calendar="gregorian">
              <xsl:attribute name="normal">
                <xsl:value-of select="user:current_date()"/>
              </xsl:attribute>
              <xsl:value-of select="user:current_date()"/>
            </date>
          </creation>

          <langusage> Finding aid written in <language langcode="eng" encodinganalog="language"
              scriptcode="latn">English.</language>
          </langusage>
          <descrules>Finding aid based on DACS (<title render="italic">Describing Archives: A Content Standard</title>)</descrules>
        </profiledesc>
      </eadheader>
      <xsl:apply-templates/>
    </ead>
  </xsl:template>

  <xsl:template match="marc:record">

    <!-- These variables will be used for generating scopecontent, bioghist, and abstract -->
    <xsl:variable name="f520" select="marc:datafield[@tag=520]/marc:subfield[@code='a']/." />
    <xsl:variable name="f545" select="marc:datafield[@tag=545]/marc:subfield[@code='a']/." />
    
    <archdesc level="collection" type="inventory" relatedencoding="marc21">
      <did id="a1">

        <repository>
          <corpname encodinganalog="852$a"> Oregon Historical Society <subarea
              encodinganalog="852$b">Research Library</subarea>
          </corpname>
          <address>
            <addressline>Oregon Historical Society Davies Family Research Library</addressline>
            <addressline>Portland, OR  97205</addressline>
            <addressline>503-306-5205</addressline>
            <addressline>http://www.ohs.org/</addressline>
            <addressline>libreference@ohs.org</addressline>
          </address>
        </repository>
        <unitid encodinganalog="099" countrycode="us" repositorycode="orhi">
          <xsl:if test="//marc:record/marc:datafield[@tag=099]">
            <xsl:value-of select="//marc:record/marc:datafield[@tag=099]/marc:subfield[@code='a']/."
            />
          </xsl:if>
        </unitid>

        <xsl:for-each select="marc:datafield[@tag=100]">
          <origination>
            <persname encodinganalog="100" source="lcnaf" role="creator" rules="dacs">
              <xsl:value-of select="."/>
            </persname>
          </origination>
        </xsl:for-each>
        
        <xsl:for-each select="marc:datafield[@tag=110]">
          <origination>
            <corpname encodinganalog="110" source="lcnaf" role="creator" rules="dacs">
              <xsl:value-of select="." />
            </corpname>
          </origination>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=245]">
          <unittitle encodinganalog="245$a" type="collection">
            <xsl:value-of select="marc:subfield[@code='a']"/>
          </unittitle>

          <xsl:if test="marc:subfield[@code='f']!=''">
            <unitdate type="inclusive" era="ce" calendar="gregorian" encodinganalog="245$f">
              <xsl:if test="contains(marc:subfield[@code='f'], 'circa') or contains(marc:subfield[@code='f'], 'approximate')">
                <xsl:attribute name="certainty">approximate</xsl:attribute>
              </xsl:if>
              <xsl:attribute name="normal">
                <xsl:value-of select="translate(translate(marc:subfield[@code='f'],'.', ''), '-', '/')"/>
              </xsl:attribute>
              <xsl:value-of select="translate(marc:subfield[@code='f'], '.', '')"/>
            </unitdate>
          </xsl:if>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=300]">
          <physdesc>

            <xsl:if test="marc:subfield[@code='a']!=''">
              <extent encodinganalog="300$a">
                <xsl:value-of select="marc:subfield[@code='a']"/>
                <xsl:if test="marc:subfield[@code='f']!=''">
                  <xsl:text> </xsl:text>
                  <xsl:value-of select="marc:subfield[@code='f']" />
                </xsl:if>
              </extent>
            </xsl:if>

            <xsl:if test="marc:subfield[@code='b']!=''">
              <physfacet encodinganalog="300$b">
                <xsl:value-of select="marc:subfield[@code='b']"/>
              </physfacet>
            </xsl:if>

            <xsl:if test="marc:subfield[@code='c']!=''">
              <dimensions encodinganalog="300$c">
                <xsl:value-of select="marc:subfield[@code='c']"/>
              </dimensions>
            </xsl:if>
            
            <xsl:if test="marc:subfield[@code='f']!='' and marc:subfield[@code='a']=''">
              <extent encodinganalog="300$a">
                <xsl:value-of select="marc:subfield[@code='f']" />
              </extent>
            </xsl:if>

          </physdesc>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=254]">
          <materialspec encodinganalog="254">
            <xsl:value-of select="."/>
          </materialspec>
        </xsl:for-each>
        
              
        <!--
        The abstract is generally a combination of information found in the scopecontent element and the bioghist.  
        Ideally, this field would be human created, but for automated purposes, we will combine the data from the 
        scopecontent note and the bioghist...using the first sentence of the field and combining them together.
        -->

        <abstract encodinganalog="5203_">
          <xsl:value-of select="user:BuildAbstract(string($f520),string($f545))"/>
        </abstract>

        <xsl:for-each select="marc:datafield[@tag=852]">
          <physloc encodinganalog="852$z">
            <xsl:value-of select="marc:subfield[@code='z']"/>
          </physloc>
        </xsl:for-each>

        <xsl:choose>
          <xsl:when test="marc:datafield[@tag=546]">
            <xsl:for-each select="marc:datafield[@tag=546]">
              <langmaterial>
                <language encodinganalog="546">
                  <xsl:value-of select="."/>
                </language>
              </langmaterial>
            </xsl:for-each>
          </xsl:when>
          <xsl:otherwise>
            <langmaterial>
              <language encodinganalog="546" langcode="Eng">English</language>
            </langmaterial>
          </xsl:otherwise>
        </xsl:choose>
      </did>

      <xsl:for-each select="marc:datafield[@tag=538]">
        <phystech encodinganalog="538">
          <p>
            <xsl:value-of select="."/>
          </p>
        </phystech>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=535]">
        <originalsloc encodinganalog="535">
          <p>
            <xsl:value-of select="."/>
          </p>
        </originalsloc>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=545]">
        <bioghist encodinganalog="545" id="a2">
          <!--Use heading Historical Note for corporate history-->
          <p>
            <xsl:value-of select="$f545"/>
          </p>
        </bioghist>
      </xsl:for-each>

     <xsl:for-each select="marc:datafield[@tag=520]">
          <scopecontent encodinganalog="520$a"><p>
            <xsl:value-of select="$f520"/></p>
          </scopecontent>
        </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=500]">
        <xsl:choose>
          <xsl:when test ="user:IsAcqu(string(.))='true'">
            <acqinfo encodinganalog="541" id="a19">
              <p>
                <xsl:value-of select="."/>
              </p>
            </acqinfo>
          </xsl:when>
          <xsl:otherwise>
            <odd encodinganalog="500" id="a5">
              <p>
                <xsl:value-of select="."/>
              </p>
            </odd>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=351]">
        <arrangement encodinganalog="351" id="a4">
          <p>
            <xsl:value-of select="."/>
          </p>
        </arrangement>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=530]">
        <altformavail encodinganalog="530" id="a9">
          <p>
            <xsl:value-of select="."/>
          </p>
        </altformavail>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=506]">
        <accessrestrict encodinganalog="506" id="a14">
          <p>
            <xsl:value-of select="."/>
          </p>
        </accessrestrict>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=540]">
        <userestrict encodinganalog="540" id="a15">
          <p>
            <xsl:value-of select="."/>
          </p>
        </userestrict>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=524]">
        <prefercite encodinganalog="524" id="a18">
          <p>
            <xsl:value-of select="."/>
          </p>
        </prefercite>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=561]">
        <custodhist encodinganalog="561" id="a16">
          <p>
            <xsl:value-of select="."/>
          </p>
        </custodhist>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=541]">
        <acqinfo encodinganalog="541" id="a19">
          <p>
            <xsl:value-of select="."/>
          </p>
        </acqinfo>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=584]">
        <accruals encodinganalog="584" id="a10">
          <p>
            <xsl:value-of select="."/>
          </p>
        </accruals>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=538]">
        <processinfo encodinganalog="583" id="a20">
          <p>
            <xsl:value-of select="."/>
          </p>
        </processinfo>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=544]">
        <separatedmaterial encodinganalog="544 0" id="a7">
          <p>
            <xsl:value-of select="."/>
          </p>
        </separatedmaterial>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=581]">
        <bibliography encodinganalog="581" id="a11">
          <p>
            <xsl:value-of select="."/>
          </p>
        </bibliography>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=555]">
        <otherfindaid encodinganalog="555" id="a8">
          <p>
            <xsl:value-of select="."/>
          </p>
        </otherfindaid>
      </xsl:for-each>

      <xsl:for-each select="marc:datafield[@tag=544]">
        <relatedmaterial encodinganalog="544 1" id="a6">
          <p>
            <xsl:value-of select="."/>
          </p>
        </relatedmaterial>
      </xsl:for-each>

      <controlaccess id="a12">
        <xsl:for-each select="marc:datafield[@tag=600]">
          <controlaccess>
            <famname source="lcnaf" rules="aacr2r" role="subject" encodinganalog="600">
              <xsl:for-each select="marc:subfield">
                <xsl:value-of select="."/>
                <xsl:if test="position()!=last()">
                  <xsl:text> -- </xsl:text>
                </xsl:if>
              </xsl:for-each>
            </famname>
          </controlaccess>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=610]">
          <controlaccess>
            <corpname source="lcnaf" rules="aacr2r" role="subject" encodinganalog="610">
              <xsl:for-each select="marc:subfield">
                <xsl:value-of select="."/>
                <xsl:if test="position()!=last()">
                  <xsl:text> -- </xsl:text>
                </xsl:if>
              </xsl:for-each>
            </corpname>
          </controlaccess>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=651]">
          <controlaccess>
            <geogname source="lcsh" rules="scm" role="subject" encodinganalog="651">
              <xsl:for-each select="marc:subfield">
                <xsl:value-of select="."/>
                <xsl:if test="position()!=last()">
                  <xsl:text> -- </xsl:text>
                </xsl:if>
              </xsl:for-each>
            </geogname>
          </controlaccess>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=650]">
          <controlaccess>
            <subject source="lcsh" encodinganalog="650" rules="scm">
              <xsl:for-each select="marc:subfield">
                <xsl:value-of select="."/>
                <xsl:if test="position()!=last()">
                  <xsl:text> -- </xsl:text>
                </xsl:if>
              </xsl:for-each>
            </subject>
          </controlaccess>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=655]">
          <controlaccess>
            <genreform source="lcsh" encodinganalog="655">
              <xsl:for-each select="marc:subfield">
                <xsl:value-of select="."/>
                <xsl:if test="position()!=last()">
                  <xsl:text> -- </xsl:text>
                </xsl:if>
              </xsl:for-each>
            </genreform>
          </controlaccess>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=656]">
          <controlaccess>
            <occupation source="lcsh" encodinganalog="656">
              <xsl:for-each select="marc:subfield">
                <xsl:value-of select="."/>
                <xsl:if test="position()!=last()">
                  <xsl:text> -- </xsl:text>
                </xsl:if>
              </xsl:for-each>
            </occupation>
          </controlaccess>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=657]">
          <controlaccess>
            <function source="aat" encodinganalog="657">
              <xsl:for-each select="marc:subfield">
                <xsl:value-of select="."/>
                <xsl:if test="position()!=last()">
                  <xsl:text> -- </xsl:text>
                </xsl:if>
              </xsl:for-each>
            </function>
          </controlaccess>
        </xsl:for-each>

        <xsl:for-each select="marc:datafield[@tag=630]">
          <controlaccess>
            <title encodinganalog="630" source="lcnaf" rules="aacr2r">
              <xsl:for-each select="marc:subfield">
                <xsl:value-of select="."/>
                <xsl:if test="position()!=last()">
                  <xsl:text> -- </xsl:text>
                </xsl:if>
              </xsl:for-each>
            </title>
          </controlaccess>
        </xsl:for-each>
        
        <xsl:for-each select="marc:datafield[@tag=690]">
          <controlaccess>
            <subject altrender="nodisplay" source="nwda" encodinganalog="690">
              <xsl:for-each select="marc:subfield">
                <xsl:value-of select="."/>
                <xsl:if test="position()!=last()">
                  <xsl:text> -- </xsl:text>
                </xsl:if>
              </xsl:for-each>
            </subject>
          </controlaccess>
        </xsl:for-each>
        
        <controlaccess>
          <subject altrender="nodisplay" source="nwda" encodinganalog="690">Oregon</subject>
        </controlaccess>
      </controlaccess>
    </archdesc>
  </xsl:template>
</xsl:stylesheet>
