<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"  
xmlns:marc="http://www.loc.gov/MARC21/slim"
xmlns:rdxdmd="http://www.RDXDMD.com/XMLSchema-instance"
 xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform" exclude-result-prefixes="rdxdmd">
	<xsl:output method="xml" indent="yes" />
	
	<xsl:template match="/">
		<marc:collection
			xmlns:marc="http://www.loc.gov/MARC21/slim" 
			xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
			xsi:schemaLocation="http://www.loc.gov/MARC21/slim http://www.loc.gov/standards/marcxml/schema/MARC21slim.xsd">
			<marc:record>
				<marc:leader>00000nmm  2200000Ia 4500</marc:leader>
				<marc:controlfield tag="007">cr\cn|||||||||</marc:controlfield>
				<marc:datafield tag="042" ind1=" " ind2=" ">
					<marc:subfield code="a">rdxdmd</marc:subfield>
				</marc:datafield>
				<xsl:call-template name="title" />
				<xsl:call-template name="source" />
				<xsl:call-template name="Physical_Description" />
				<xsl:call-template name="Notes" />
				<datafield tag="538" ind1=" " ind2=" ">
					<subfield code="a">Mode of access: World Wide Web.</subfield>
				</datafield>
				<xsl:call-template name="language" />
				<xsl:call-template name="rights" />
				<xsl:call-template name="Name_Subject" />
				<xsl:call-template name="Topics_Subject" />
				<xsl:call-template name="creator" />
				<xsl:call-template name="URL" />
			</marc:record>
		</marc:collection>
	</xsl:template>
	
	<xsl:template name="URL">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:resourceIdentifier">
			<marc:datafield tag="856" ind1="4" ind2="1">
				<marc:subfield code="u"><xsl:value-of select="." /></marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="creator">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:creator">
			<xsl:choose>
				<xsl:when test="@creatorRole='Congressional Corporate Body Name' or @creatorRole='Congressional Standing Committee Name'">
					<marc:datafield tag="710" ind1="2" ind2=" ">
						<xsl:choose>
							<xsl:when test="contains(.,'. ')">
								<marc:subfield code="a"><xsl:value-of select="substring-before(., '. ')" />.</marc:subfield>
								<xsl:call-template name="csplit">
									<xsl:with-param name="subfield" select="'b'" />
									<xsl:with-param name="del" select="'. '" />
									<xsl:with-param name="string" select="substring-after(., '. ')" />
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<marc:subfield code="a"><xsl:value-of select="." />.</marc:subfield>
							</xsl:otherwise>
						</xsl:choose>
					</marc:datafield>
				</xsl:when>
				<xsl:otherwise>
					<marc:datafield tag="710" ind1="2" ind2=" ">
						<marc:subfield code="a"><xsl:value-of select="." />.</marc:subfield>
					</marc:datafield>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="title">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:title">
			<xsl:choose>
				<xsl:when test="@titleType='Main'">
					<marc:datafield tag="245" ind1="1" ind2="0">
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
						<marc:subfield code="h">[electronic resource]</marc:subfield>
					</marc:datafield>
				</xsl:when>
				<xsl:otherwise>
					<marc:datafield tag="740" ind1="1" ind2="0">
						<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					</marc:datafield>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Physical_Description">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:description">
			<xsl:if test="@descriptionSource='Physical Description'">
				<xsl:choose>
					<xsl:when test="contains(.,':')">
						<marc:datafield tag="300" ind1=" " ind2=" ">
							<marc:subfield code="a"><xsl:value-of select="substring-before(.,':')" /> : </marc:subfield>
							<marc:subfield code="b"><xsl:value-of select="substring-after(.,':')" />.</marc:subfield>
						</marc:datafield>
					</xsl:when>
					<xsl:otherwise>
						<marc:datafield tag="300" ind1=" " ind2=" ">
							<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
						</marc:datafield>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	
	<xsl:template name="Genre_Description">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:description">
			<xsl:if test="@descriptionSource='Genres'">
				<marc:datafield tag="655" ind1=" " ind2="7">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<marc:subfield code="2">rdxdmd</marc:subfield>
				</marc:datafield>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
			
	
	<xsl:template name="Topics_Subject">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:subject">
			<xsl:if test="@subjectType='Topical'">
				<marc:datafield tag="650" ind1=" " ind2="7">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<marc:subfield code="2">rdxdmd</marc:subfield>
				</marc:datafield>
			</xsl:if>
			
			<xsl:if test="@subjectType='Group of People'">
				<marc:datafield tag="650" ind1=" " ind2="7">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<marc:subfield code="2">rdxdmd</marc:subfield>
				</marc:datafield>
			</xsl:if>
			
			<xsl:if test="@subjectType='Aspect'">
				<marc:datafield tag="650" ind1=" " ind2="7">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
					<marc:subfield code="2">rdxdmd</marc:subfield>
				</marc:datafield>
			</xsl:if>
			
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Name_Subject">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:subject">
			<xsl:if test="@subjectType='Corporate Body Name'">
				<marc:datafield tag="610" ind1="2" ind2=" ">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
				</marc:datafield>
			</xsl:if>
			
			<xsl:if test="@subjectType='Executive Department Name'">
				<marc:datafield tag="610" ind1="2" ind2=" ">
					<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
				</marc:datafield>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Notes">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:coverage">
			<marc:datafield tag="500" ind1=" " ind2=" ">
				<marc:subfield code="a"><xsl:value-of select="." />.</marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="language">
		<marc:datafield tag="546" ind1=" " ind2=" ">
			<marc:subfield code="a"><xsl:value-of select="rdxdmd:RDXDmd/rdxdmd:language" />.</marc:subfield>
		</marc:datafield>
	</xsl:template>
	
	<xsl:template name="source">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:source">
			<marc:datafield tag="260" ind1=" " ind2=" ">
				<marc:subfield code="a"><xsl:value-of select="@sourcePublicationPlace" /> : </marc:subfield>
				<marc:subfield code="b"><xsl:value-of select="@sourceSerialSetVolumeAndPublicationNumber" />, </marc:subfield>
				<marc:subfield code="c"><xsl:value-of select="substring(@sourcePublicationDate, 1,4)" />.</marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="rights">
		<xsl:for-each select="rdxdmd:RDXDmd/rdxdmd:rightsStatement">
			<marc:datafield tag="506" ind1=" " ind2=" ">
				<marc:subfield code="a"><xsl:value-of select="." /></marc:subfield>
			</marc:datafield>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="csplit">
		<xsl:param name="subfield" />
		<xsl:param name="del" />
		<xsl:param name="string" />
		
		<xsl:choose>
			<xsl:when test="contains($string, $del)">
				<marc:subfield>
					<xsl:attribute name="code"><xsl:value-of select="$subfield" /></xsl:attribute><xsl:value-of select="substring-before($string, $del)" />.</marc:subfield>
					<xsl:call-template name="csplit">
						<xsl:with-param name="subfield" select="'b'" />
						<xsl:with-param name="del" select="'. '" />
						<xsl:with-param name="string" select="substring-after($string, $del)" />
					</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="$string!=''">
					<marc:subfield>
						<xsl:attribute name="code"><xsl:value-of select="$subfield" /></xsl:attribute><xsl:value-of select="$string" /></marc:subfield>
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>